==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/de.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Passwort:",
    "Generating system report failed." : "Erstellung des System-Berichts fehlgeschlagen.",
    "Subscription notifications" : "Abonnements-Benachrichtigungen",
    "Could not create folder \"System information\" to store generated report." : "Ordner \"System information\" konnte nicht erstellt werden, um den erstellten Bericht zu speichern.",
    "Could not create file \"%s\" to store generated report." : "Die Datei \"%s\" konnte nicht erstellt werden, um in ihr den erstellten Bericht zu speichern.",
    "Could not share file \"%s\"." : "Die Datei \"%s\" konnte nicht freigegeben werden.",
    "Nextcloud Subscription" : "Nextcloud-Abonnement",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Dein Server hat kein Nextcloud-Abonnement oder Dein Abonnement ist abgelaufen.",
    "Your Nextcloud server subscription does not cover your number of users." : "Dein Nexcloud-Abonnement umfasst nicht die Anzahl Deiner Nutzer",
    "Your Nextcloud Subscription has expired!" : "Dein Nextcloud-Abonnement ist abgelaufen!",
    "Your server has no Nextcloud Subscription or your Subscription has expired" : "Dein Server hat kein Nextcloud-Abonnement oder Dein Abonnement ist abgelaufen",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Dein Server wird nicht von einem Nextcloud-Enterprise-Abonnement umfasst.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Ein Nextcloud-Support-Abonnement bedeutet, dass sich die Entwickler Deiner privaten Cloud-Server zu 100 % Deinem Erfolg widmen: der Sicherheit, Skalierbarkeit, Leistung und Funktionalität Deines Dienstes.",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Wenn Du auf ein Problem stößt und Dein Server nicht länger funktioniert, Mitarbeiter oder Kunden keine Dateien mehr herunter- oder hochladen können, dann musst Du nicht online suchen oder Freiwillige in Foren oder Sozialen Medien fragen, um eine Lösung zu finden. Du hast direkten Zugang zu unseren erfahrenen Entwicklern, welche DIr helfen, das Problem zu finden und zu beheben.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Du hast einen Vertrag mit dem Anbieter, der Dir vertrauliche Sicherheitsinformationen, Risikominimierungen, Patches und Aktualisierungen bereitstellt.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Wenn Du ein oder zwei Versionen überspringen möchtest und etwas länger Deine installierte Version ohne Unterbrechung behalten möchtest, musst Du auf Sicherheitsupdates nicht verzichten. Wir liefern diese so lange, wie es erforderlich ist.",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Wenn Du Leistungs- oder Skalierungsprobleme haben solltest, hast Du direkt die größte Erfahrung zur Hand und musst nicht das Netz in der Hoffnung, eine Lösung zu finden, durchsuchen.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Wenn Du bezüglich der Compliance von Nextcloud gefragt wirst, kannst Du einen Datenexport liefern, der der DSGVO, der HIPAA oder anderen Regelungen entspricht. Außerdem hast Du Zugriff auf die erforderlichen Dokumentation und unsere Erfahrung, um schnell und vollständig antworten zu können.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Wir können auch Outlook-Integration, Online-Office, skalierbare integrierte Audio-, Video- und Chat-Kommunikation sowie weitere Funktionen, die sonst nur in beschränkter Form kostenlos erhältlich sind, anbieten. Ausserdem können wir weitere Erweiterungen, die benötigt werden, entwickeln.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Ein Abonnement hilft Dir, das meiste aus Nexcloud herauszuholen! Haben Deine Nutzer nicht das Beste verdient?",
    "You received this email because you are an admin of the Nextcloud instance at %s." : "Du hast diese E-Mail erhalten, weil du ein Admin der Nextcloud-Instanz unter %s bist.",
    "Learn more now" : "Erfahre jetzt mehr",
    "Your Nextcloud server Subscription is over limit" : "Dein Nextcloud-Server-Abonnement ist über dem Limit",
    "Dear admin," : "Lieber Adminstrator,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Dein Nextcloud-Abonnement umfasst nicht die Anzahl der aktuell auf diesem Server aktiven Nutzer. Bitte kontaktiere Deinen Accountmanager, um Dein Abonnement aktualisieren zu lassen!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s ist Dein Accountmanager und ist per E-Mail über  %2$s oder telefonisch unter %3$s erreichbar.",
    "Thank you," : "Dankeschön,",
    "Your Nextcloud team" : "Dein Nextcloud-Team",
    "Your Nextcloud server Subscription is expired" : "Dein Nextcloud-Server-Abonnement ist abgelaufen",
    "Your Nextcloud server Subscription is expired!" : "Dein Nextcloud-Server-Abonnement ist abgelaufen!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Dein Nextcloud Abonnement ist abgelaufen! Bitte kontaktiere Deinen Accountmanager, um das Abonnement verlängert zu bekommen.",
    "Support" : "Support",
    "Getting support and help for your Nextcloud" : "Erhalte Support und Hilfe für Deine Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Die Support-App bietet direkten Zugriff auf Hilfe- und Vertriebsquellen, direkte Kontaktmöglichkeiten zum Konten-Verwalter sowie einen Überblick über das Enterprise-Abonnement.",
    "Basic subscription" : "Basis Abonnement",
    "Standard subscription" : "Standard Abonnement",
    "Premium subscription" : "Premium Abonnement",
    "Géant subscription" : "Géant Abonnement",
    "Silver partner subscription" : "Silber-Partner Abonnement",
    "Gold partner subscription" : "Gold-Partner Abonnement",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Abonnements-Limit überschritten",
    "Valid subscription" : "Gültiges Abonnement",
    "Expired subscription" : "Abgelaufenes Abonnement",
    "Subscription key:" : "Abonnements-Schlüssel:",
    "_Expires in %n year_::_Expires in %n years_" : ["Läuft ab in %n Jahr","Läuft ab in %n Jahren"],
    "_Expires in %n month_::_Expires in %n months_" : ["Läuft ab in %n Monat","Läuft ab in %n Monaten"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Läuft ab in %n Woche","Läuft ab in %n Wochen"],
    "_Expires in %n day_::_Expires in %n days_" : ["Läuft ab in %n Tage","Läuft ab in %n Tagen"],
    "_For %n users_::_For %n users_" : ["Für %n  Nutzer","Für %n Nutzer"],
    "_currently at %n user_::_currently at %n users_" : ["aktuell mit %n  Nutzer","aktuell mit %n  Nutzern"],
    "Includes support for %s" : "Beinhaltet Support für %s",
    "Includes support for %1$s & %2$s" : "Beinhaltet Support für %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Beinhaltet Support für %1$s, %2$s & %3$s",
    "Update subscription key" : "Abonnements-Schlüssel aktualisieren",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s ist Dein Accountmanager. Zögere nicht, uns bezüglich Fragen zu Deinem Abonnement anzusprechen.",
    "You can find answers to common question in our portal and also file support requests there." : "In unserem Portal findest Du Antworten auf häufige Fragen und kannst auch Unterstützung anfordern.",
    "Access Nextcloud portal" : "Zum Nextcloud-Portal",
    "System information" : "Systeminformation",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Erstellen von Systeminformationen für Supportfälle. Nach Betätigung der Schaltfläche wird eine Textdatei im Ordner \"System Information\" erstellt und über eine passwortgeschütze, öffentliche Freigabe geteilt. Der Link ist 2 Wochen lang aktiv.",
    "Generate system report" : "System-Bericht erstellen",
    "Enterprise subscription recommended" : "Enterprise-Abonnement empfohlen",
    "No active enterprise subscription" : "Kein aktives Enterprise-Abonnement",
    "Unsupported" : "Nicht unterstützt",
    "This Nextcloud server has no Enterprise Subscription." : "Dieser Nextcloud-Server verfügt über kein Enterprise-Abonnement.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Ein Nextcloud Enterprise-Abonnenment hilft Dir, das meiste aus Deiner Nextcloud herauszuholen, Deine Daten abzusichern und Deinen Server jederzeit zuverlässig zu betreiben.",
    "Advantages" : "Vorteile",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Zugriff auf die technische Erfahrung der Nextcloud-Entwickler über die Dokumentation und den Support",
    "Access to additional capabilities like Outlook integration, online office and more" : "Zugriff auf weitere Funktionen wie Outlook-Integration, Online-Office, usw.",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Zugriff auf Skalierbarkeits-Sachverstand und Skalierbarkeits-Fähigkeiten für Dateien und Talk",
    "Optional branding, consulting, architecture advice" : "Optionale Unterstützung bezüglich Branding, Beratung und Architektur",
    "Confidential security notification service, mitigations, patches and advice" : "Vertraulicher Sicherheitsbenachrichtigungsdienst, Risikominderung, Patches und Hilfestellungen",
    "Compliance certification, advice and documentation" : "Compliance-Zertifizierung, Beratung und Dokumentation",
    "Get a quote" : "Erhalte ein Angebot",
    "More information" : "Mehr Informationen",
    "Subscription benefits" : "Vorteile eines Abonnements",
    "Pricing" : "Preisgestaltung",
    "Commmunity support" : "Community-Unterstützung",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud ist eine freie Software, die von einer sehr aktive Community unterstützt wird. Bitte melde Dich im Forum an, um Fragen zu stellen oder mit anderen zu diskutieren.",
    "Nextcloud forum" : "Nextcloud Forum",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud verwendet GitHub als Plattform für die Zusammenarbeit. Du kannst dort Fehler direkt melden.",
    "Nextcloud at GitHub" : "Nextcloud auf GitHub",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Chatte mit uns über den IRC-Kanal #nextcloud auf Freenode.",
    "Open chat" : "Chat öffnen",
    "Subscription key" : "Abonnements-Schlüssel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Wenn Du über ein aktives Nextcloud-Abonnement verfügst, gebe bitte hier Deinen Abonnements-Schlüssel ein.",
    "Learn more about an enterprise subscription." : "Erfahre mehr über das Enterprise-Abonnement.",
    "Set subscription key" : "Abonnements-Schlüssel eingeben",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Die Abonnenments-Informationen konnten soeben nicht abgerufen werden. Eine Wiederholung ist geplant. Bitte später noch einmal überprüfen.",
    "The subscription key was invalid." : "Der Abonnements-Schlüssel ist ungültig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Der Abonnements-Schlüssel konnte nicht überprüft werden, da dieser Server nicht mit dem Internet verbunden ist. Bitte wende Dich zur Fehlerbehebung an das Support-Team.",
    "The subscription key had an invalid format." : "Der Abonnements-Schlüssel hat ein ungültiges Format.",
    "While fetching the subscription information an error happened." : "Beim Abruf der Abonnements-Informationen ist ein Fehler aufgetreten",
    "News" : "Neuigkeiten",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Abonniere unseren Newsletter und folge uns auf unseren Social-Media-Kanälen, um bezüglich der Nexcloud-Entwicklung immer auf dem Laufenden zu sein.",
    "Follow us on Google+" : " Folge uns auf Google+",
    "Like our Facebook page" : "Like uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folge uns auf Twitter",
    "Check out our blog" : "Sieh Dir unseren Blog an",
    "Subscribe to our newsletter" : "Abonniere unseren Newsletter"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/de.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Passwort:",
    "Generating system report failed." : "Erstellung des System-Berichts fehlgeschlagen.",
    "Subscription notifications" : "Abonnements-Benachrichtigungen",
    "Could not create folder \"System information\" to store generated report." : "Ordner \"System information\" konnte nicht erstellt werden, um den erstellten Bericht zu speichern.",
    "Could not create file \"%s\" to store generated report." : "Die Datei \"%s\" konnte nicht erstellt werden, um in ihr den erstellten Bericht zu speichern.",
    "Could not share file \"%s\"." : "Die Datei \"%s\" konnte nicht freigegeben werden.",
    "Nextcloud Subscription" : "Nextcloud-Abonnement",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Dein Server hat kein Nextcloud-Abonnement oder Dein Abonnement ist abgelaufen.",
    "Your Nextcloud server subscription does not cover your number of users." : "Dein Nexcloud-Abonnement umfasst nicht die Anzahl Deiner Nutzer",
    "Your Nextcloud Subscription has expired!" : "Dein Nextcloud-Abonnement ist abgelaufen!",
    "Your server has no Nextcloud Subscription" : "Dein Server hat kein Nextcloud-Abonnement",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Dein Server wird nicht von einem Nextcloud-Enterprise-Abonnement umfasst.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Ein Nextcloud-Support-Abonnement bedeutet, dass sich die Entwickler Deiner privaten Cloud-Server zu 100 % Deinem Erfolg widmen: der Sicherheit, Skalierbarkeit, Leistung und Funktionalität Deines Dienstes.",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Wenn Du auf ein Problem stößt und Dein Server nicht länger funktioniert, Mitarbeiter oder Kunden keine Dateien mehr herunter- oder hochladen können, dann musst Du nicht online suchen oder Freiwillige in Foren oder Sozialen Medien fragen, um eine Lösung zu finden. Du hast direkten Zugang zu unseren erfahrenen Entwicklern, welche DIr helfen, das Problem zu finden und zu beheben.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Du hast einen Vertrag mit dem Anbieter, der Dir vertrauliche Sicherheitsinformationen, Risikominimierungen, Patches und Aktualisierungen bereitstellt.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Wenn Du ein oder zwei Versionen überspringen möchtest und etwas länger Deine installierte Version ohne Unterbrechung behalten möchtest, musst Du auf Sicherheitsupdates nicht verzichten. Wir liefern diese so lange, wie es erforderlich ist.",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Wenn Du Leistungs- oder Skalierungsprobleme haben solltest, hast Du direkt die größte Erfahrung zur Hand und musst nicht das Netz in der Hoffnung, eine Lösung zu finden, durchsuchen.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Wenn Du bezüglich der Compliance von Nextcloud gefragt wirst, kannst Du einen Datenexport liefern, der der DSGVO, der HIPAA oder anderen Regelungen entspricht. Außerdem hast Du Zugriff auf die erforderlichen Dokumentation und unsere Erfahrung, um schnell und vollständig antworten zu können.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Wir können auch Outlook-Integration, Online-Office, skalierbare integrierte Audio-, Video- und Chat-Kommunikation sowie weitere Funktionen, die sonst nur in beschränkter Form kostenlos erhältlich sind, anbieten. Ausserdem können wir weitere Erweiterungen, die benötigt werden, entwickeln.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Ein Abonnement hilft Dir, das meiste aus Nexcloud herauszuholen! Haben Deine Nutzer nicht das Beste verdient?",
    "Learn more now" : "Erfahre jetzt mehr",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Diese E-Mail wurde von der Support-App deiner Nextcloud-Instanz unter %1$s an alle Administratoren verschickt, weil über %2$s registrierte Benutzer vorhanden sind.",
    "Your Nextcloud server Subscription is over limit" : "Dein Nextcloud-Server-Abonnement ist über dem Limit",
    "Dear admin," : "Lieber Adminstrator,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Dein Nextcloud-Abonnement umfasst nicht die Anzahl der aktuell auf diesem Server aktiven Nutzer. Bitte kontaktiere Deinen Accountmanager, um Dein Abonnement aktualisieren zu lassen!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s ist Dein Accountmanager und ist per E-Mail über  %2$s oder telefonisch unter %3$s erreichbar.",
    "Thank you," : "Dankeschön,",
    "Your Nextcloud team" : "Dein Nextcloud-Team",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Diese E-Mail wurde von der Support-App deiner Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil mehr Benutzer registriert sind als das Nextcloud-Abonnement abdeckt.",
    "Your Nextcloud server Subscription is expired" : "Dein Nextcloud-Server-Abonnement ist abgelaufen",
    "Your Nextcloud server Subscription is expired!" : "Dein Nextcloud-Server-Abonnement ist abgelaufen!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Dein Nextcloud Abonnement ist abgelaufen! Bitte kontaktiere Deinen Accountmanager, um das Abonnement verlängert zu bekommen.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Diese E-Mail wurde von der Support-App deiner Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil dein Nextcloud-Abonnement abgelaufen ist.",
    "Support" : "Support",
    "Getting support and help for your Nextcloud" : "Erhalte Support und Hilfe für Deine Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Die Support-App bietet direkten Zugriff auf Hilfe- und Vertriebsquellen, direkte Kontaktmöglichkeiten zum Konten-Verwalter sowie einen Überblick über das Enterprise-Abonnement.",
    "Basic subscription" : "Basis Abonnement",
    "Standard subscription" : "Standard Abonnement",
    "Premium subscription" : "Premium Abonnement",
    "Géant subscription" : "Géant Abonnement",
    "Silver partner subscription" : "Silber-Partner Abonnement",
    "Gold partner subscription" : "Gold-Partner Abonnement",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Abonnements-Limit überschritten",
    "Valid subscription" : "Gültiges Abonnement",
    "Expired subscription" : "Abgelaufenes Abonnement",
    "Subscription key:" : "Abonnements-Schlüssel:",
    "_Expires in %n year_::_Expires in %n years_" : ["Läuft ab in %n Jahr","Läuft ab in %n Jahren"],
    "_Expires in %n month_::_Expires in %n months_" : ["Läuft ab in %n Monat","Läuft ab in %n Monaten"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Läuft ab in %n Woche","Läuft ab in %n Wochen"],
    "_Expires in %n day_::_Expires in %n days_" : ["Läuft ab in %n Tage","Läuft ab in %n Tagen"],
    "_For %n users_::_For %n users_" : ["Für %n  Nutzer","Für %n Nutzer"],
    "_currently at %n user_::_currently at %n users_" : ["aktuell mit %n  Nutzer","aktuell mit %n  Nutzern"],
    "Includes support for %s" : "Beinhaltet Support für %s",
    "Includes support for %1$s & %2$s" : "Beinhaltet Support für %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Beinhaltet Support für %1$s, %2$s & %3$s",
    "Update subscription key" : "Abonnements-Schlüssel aktualisieren",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s ist Dein Accountmanager. Zögere nicht, uns bezüglich Fragen zu Deinem Abonnement anzusprechen.",
    "You can find answers to common question in our portal and also file support requests there." : "In unserem Portal findest Du Antworten auf häufige Fragen und kannst auch Unterstützung anfordern.",
    "Access Nextcloud portal" : "Zum Nextcloud-Portal",
    "System information" : "Systeminformation",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Erstellen von Systeminformationen für Supportfälle. Nach Betätigung der Schaltfläche wird eine Textdatei im Ordner \"System Information\" erstellt und über eine passwortgeschütze, öffentliche Freigabe geteilt. Der Link ist 2 Wochen lang aktiv.",
    "Generate system report" : "System-Bericht erstellen",
    "Enterprise subscription recommended" : "Enterprise-Abonnement empfohlen",
    "No active enterprise subscription" : "Kein aktives Enterprise-Abonnement",
    "Unsupported" : "Nicht unterstützt",
    "This Nextcloud server has no Enterprise Subscription." : "Dieser Nextcloud-Server verfügt über kein Enterprise-Abonnement.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Ein Nextcloud Enterprise-Abonnenment hilft Dir, das meiste aus Deiner Nextcloud herauszuholen, Deine Daten abzusichern und Deinen Server jederzeit zuverlässig zu betreiben.",
    "Advantages" : "Vorteile",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Zugriff auf die technische Erfahrung der Nextcloud-Entwickler über die Dokumentation und den Support",
    "Access to additional capabilities like Outlook integration, online office and more" : "Zugriff auf weitere Funktionen wie Outlook-Integration, Online-Office, usw.",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Zugriff auf Skalierbarkeits-Sachverstand und Skalierbarkeits-Fähigkeiten für Dateien und Talk",
    "Optional branding, consulting, architecture advice" : "Optionale Unterstützung bezüglich Branding, Beratung und Architektur",
    "Confidential security notification service, mitigations, patches and advice" : "Vertraulicher Sicherheitsbenachrichtigungsdienst, Risikominderung, Patches und Hilfestellungen",
    "Compliance certification, advice and documentation" : "Compliance-Zertifizierung, Beratung und Dokumentation",
    "Get a quote" : "Erhalte ein Angebot",
    "More information" : "Mehr Informationen",
    "Subscription benefits" : "Vorteile eines Abonnements",
    "Pricing" : "Preisgestaltung",
    "Commmunity support" : "Community-Unterstützung",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud ist eine freie Software, die von einer sehr aktive Community unterstützt wird. Bitte melde Dich im Forum an, um Fragen zu stellen oder mit anderen zu diskutieren.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud verwendet GitHub als Plattform für die Zusammenarbeit. Du kannst dort Fehler direkt melden.",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Chatte mit uns über den IRC-Kanal #nextcloud auf Freenode.",
    "Nextcloud forum" : "Nextcloud Forum",
    "Nextcloud at GitHub" : "Nextcloud auf GitHub",
    "Open chat" : "Chat öffnen",
    "Subscription key" : "Abonnements-Schlüssel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Wenn Du über ein aktives Nextcloud-Abonnement verfügst, gebe bitte hier Deinen Abonnements-Schlüssel ein.",
    "Learn more about an enterprise subscription." : "Erfahre mehr über das Enterprise-Abonnement.",
    "Set subscription key" : "Abonnements-Schlüssel eingeben",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Die Abonnenments-Informationen konnten soeben nicht abgerufen werden. Eine Wiederholung ist geplant. Bitte später noch einmal überprüfen.",
    "The subscription key was invalid." : "Der Abonnements-Schlüssel ist ungültig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Der Abonnements-Schlüssel konnte nicht überprüft werden, da dieser Server nicht mit dem Internet verbunden ist. Bitte wende Dich zur Fehlerbehebung an das Support-Team.",
    "The subscription key had an invalid format." : "Der Abonnements-Schlüssel hat ein ungültiges Format.",
    "While fetching the subscription information an error happened." : "Beim Abruf der Abonnements-Informationen ist ein Fehler aufgetreten",
    "News" : "Neuigkeiten",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Abonniere unseren Newsletter und folge uns auf unseren Social-Media-Kanälen, um bezüglich der Nexcloud-Entwicklung immer auf dem Laufenden zu sein.",
    "Follow us on Google+" : " Folge uns auf Google+",
    "Like our Facebook page" : "Like uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folge uns auf Twitter",
    "Check out our blog" : "Sieh Dir unseren Blog an",
    "Subscribe to our newsletter" : "Abonniere unseren Newsletter"
},
"nplurals=2; plural=(n != 1);");
